@@ -147,6 +147,7 @@ def open_files(
     num=1,
     protocol=None,
     newline=None,
+    auto_mkdir=True,
     **kwargs
 ):
     """ Given a path or paths, return a list of ``OpenFile`` objects.
@@ -182,6 +183,9 @@ def open_files(
     newline: bytes or None
         Used for line terminator in text mode. If None, uses system default;
         if blank, uses no translation.
+    auto_mkdir: bool (True)
+        If in write mode, this will ensure the target directory exists before
+        writing, by calling ``fs.mkdirs(exist_ok=True)``.
     **kwargs: dict
         Extra options that make sense to a particular storage connection, e.g.
         host, port, username, password, etc.
@@ -225,6 +229,9 @@ def open_files(
         storage_options=kwargs,
         protocol=protocol,
     )
+    if "r" not in mode and auto_mkdir:
+        parents = {fs._parent(path) for path in paths}
+        [fs.makedirs(parent, exist_ok=True) for parent in parents]
     return [
         OpenFile(
             fs,
