@@ -7,12 +7,13 @@ pytest.importorskip("distributed")
 @pytest.fixture()
 def cli(tmpdir):
     import dask.distributed
+
     client = dask.distributed.Client(n_workers=1)
 
     def setup():
         m = fsspec.filesystem("memory")
-        with m.open('afile', 'wb') as f:
-            f.write(b'data')
+        with m.open("afile", "wb") as f:
+            f.write(b"data")
 
     client.run(setup)
     try:
@@ -23,6 +24,6 @@ def cli(tmpdir):
 
 def test_basic(cli):
 
-    fs = fsspec.filesystem('dask', remote_protocol='memory')
-    assert fs.ls('') == ['afile']
-    assert fs.cat('afile') == b'data'
+    fs = fsspec.filesystem("dask", target_protocol="memory")
+    assert fs.ls("") == ["afile"]
+    assert fs.cat("afile") == b"data"
